@@ -15,13 +15,13 @@ import qualified Command.InitRemote as InitRemote
 
 import qualified Data.Map as M
 
-def :: [Command]
-def = [command "enableremote"
+cmd :: [Command]
+cmd = [command "enableremote"
 	(paramPair paramName $ paramOptional $ paramRepeating paramKeyValue)
 	seek SectionSetup "enables use of an existing special remote"]
 
-seek :: [CommandSeek]
-seek = [withWords start]
+seek :: CommandSeek
+seek = withWords start
 
 start :: [String] -> CommandStart
 start [] = unknownNameError "Specify the name of the special remote to enable."
@@ -29,7 +29,7 @@ start (name:ws) = go =<< InitRemote.findExisting name
   where
 	config = Logs.Remote.keyValToConfig ws
 	
-  	go Nothing = unknownNameError "Unknown special remote name."
+	go Nothing = unknownNameError "Unknown special remote name."
 	go (Just (u, c)) = do
 		let fullconfig = config `M.union` c	
 		t <- InitRemote.findType fullconfig
@@ -40,14 +40,14 @@ start (name:ws) = go =<< InitRemote.findExisting name
 unknownNameError :: String -> Annex a
 unknownNameError prefix = do
 	names <- InitRemote.remoteNames
-	error $ prefix ++
+	error $ prefix ++ "\n" ++
 		if null names
-			then ""
-			else " Known special remotes: " ++ unwords names
+			then "(No special remotes are currently known; perhaps use initremote instead?)"
+			else "Known special remotes: " ++ unwords names
 
 perform :: RemoteType -> UUID -> R.RemoteConfig -> CommandPerform
 perform t u c = do
-	(c', u') <- R.setup t (Just u) c
+	(c', u') <- R.setup t (Just u) Nothing c
 	next $ cleanup u' c'
 
 cleanup :: UUID -> R.RemoteConfig -> CommandCleanup
