@@ -13,13 +13,13 @@ import Annex.UUID
 import qualified Remote.GCrypt
 import qualified Git
 
-def :: [Command]
-def = [dontCheck repoExists $ noCommit $
+cmd :: [Command]
+cmd = [dontCheck repoExists $ noCommit $
 	command "gcryptsetup" paramValue seek
 		SectionPlumbing "sets up gcrypt repository"]
 
-seek :: [CommandSeek]
-seek = [withStrings start]
+seek :: CommandSeek
+seek = withStrings start
 
 start :: String -> CommandStart
 start gcryptid = next $ next $ do
@@ -30,7 +30,7 @@ start gcryptid = next $ next $ do
 	g <- gitRepo
 	gu <- Remote.GCrypt.getGCryptUUID True g
 	let newgu = genUUIDInNameSpace gCryptNameSpace gcryptid
-	if gu == Nothing || gu == Just newgu
+	if isNothing gu || gu == Just newgu
 		then if Git.repoIsLocalBare g
 			then do
 				void $ Remote.GCrypt.setupRepo gcryptid g
