@@ -8,24 +8,26 @@
 module Command.Schedule where
 
 import Common.Annex
+import qualified Annex
 import Command
 import qualified Remote
 import Logs.Schedule
 import Types.ScheduledActivity
+import Types.Messages
 
 import qualified Data.Set as S
 
-def :: [Command]
-def = [command "schedule" (paramPair paramRemote (paramOptional paramExpression)) seek
+cmd :: [Command]
+cmd = [command "schedule" (paramPair paramRemote (paramOptional paramExpression)) seek
 	SectionSetup "get or set scheduled jobs"]
 
-seek :: [CommandSeek]
-seek = [withWords start]
+seek :: CommandSeek
+seek = withWords start
 
 start :: [String] -> CommandStart
 start = parse
   where
-  	parse (name:[]) = go name performGet
+	parse (name:[]) = go name performGet
 	parse (name:expr:[]) = go name $ \uuid -> do
 		showStart "schedile" name
 		performSet expr uuid
@@ -37,6 +39,7 @@ start = parse
 
 performGet :: UUID -> CommandPerform
 performGet uuid = do
+	Annex.setOutput QuietOutput
 	s <- scheduleGet uuid
 	liftIO $ putStrLn $ intercalate "; " $ 
 		map fromScheduledActivity $ S.toList s
