@@ -35,8 +35,8 @@ import Annex.Ssh
 
 import Control.Concurrent.MVar
 
-def :: [Command]
-def = [withOptions syncOptions $
+cmd :: [Command]
+cmd = [withOptions syncOptions $
 	command "sync" (paramOptional (paramRepeating paramRemote))
 	seek SectionCommon "synchronize local repository with remotes"]
 
@@ -122,22 +122,22 @@ syncRemotes rs = ifM (Annex.getState Annex.fast) ( nub <$> pickfast , wanted )
 	fastest = fromMaybe [] . headMaybe . Remote.byCost
 
 commit :: CommandStart
-commit = next $ next $ ifM isDirect
-	( do
-		showStart "commit" ""
-		void stageDirect
-		void preCommitDirect
-		commitStaged Git.Branch.ManualCommit commitmessage
-	, do
-		showStart "commit" ""
-		Annex.Branch.commit "update"
-		inRepo $ Git.Branch.commitQuiet Git.Branch.ManualCommit
-			[ Param "-a"
-			, Param "-m"
-			, Param commitmessage
-			]
-		return True
-	)
+commit = next $ next $ do
+	showStart "commit" ""
+	Annex.Branch.commit "update"
+	ifM isDirect
+		( do
+			void stageDirect
+			void preCommitDirect
+			commitStaged Git.Branch.ManualCommit commitmessage
+		, do
+			inRepo $ Git.Branch.commitQuiet Git.Branch.ManualCommit
+				[ Param "-a"
+				, Param "-m"
+				, Param commitmessage
+				]
+			return True
+		)
   where
 	commitmessage = "git-annex automatic sync"
 
@@ -356,7 +356,7 @@ syncFile rs f k = do
 	handleDropsFrom locs' rs "unwanted" True k (Just f)
 		Nothing callCommandAction
   where
-  	wantget have = allM id 
+	wantget have = allM id 
 		[ pure (not $ null have)
 		, not <$> inAnnex k
 		, wantGet True (Just k) (Just f)
