@@ -10,27 +10,27 @@ module Command.Watch where
 import Common.Annex
 import Assistant
 import Command
-import Option
 import Utility.HumanTime
 
-def :: [Command]
-def = [notBareRepo $ withOptions [foregroundOption, stopOption] $ 
+cmd :: [Command]
+cmd = [notBareRepo $ withOptions [foregroundOption, stopOption] $ 
 	command "watch" paramNothing seek SectionCommon "watch for changes"]
 
-seek :: [CommandSeek]
-seek = [withFlag stopOption $ \stopdaemon -> 
-	withFlag foregroundOption $ \foreground ->
-	withNothing $ start False foreground stopdaemon Nothing]
+seek :: CommandSeek
+seek ps = do
+	stopdaemon <- getOptionFlag stopOption
+	foreground <- getOptionFlag foregroundOption
+	withNothing (start False foreground stopdaemon Nothing) ps
 
 foregroundOption :: Option
-foregroundOption = Option.flag [] "foreground" "do not daemonize"
+foregroundOption = flagOption [] "foreground" "do not daemonize"
 
 stopOption :: Option
-stopOption = Option.flag [] "stop" "stop daemon"
+stopOption = flagOption [] "stop" "stop daemon"
 
 start :: Bool -> Bool -> Bool -> Maybe Duration -> CommandStart
 start assistant foreground stopdaemon startdelay = do
 	if stopdaemon
 		then stopDaemon
-		else startDaemon assistant foreground startdelay Nothing Nothing -- does not return
+		else startDaemon assistant foreground startdelay Nothing Nothing Nothing -- does not return
 	stop
