@@ -5,8 +5,6 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
-{-# LANGUAGE CPP #-}
-
 module Git.CurrentRepo where
 
 import Common
@@ -35,28 +33,24 @@ get = do
 	case wt of
 		Nothing -> return r
 		Just d -> do
-			cwd <- getCurrentDirectory
-			unless (d `dirContains` cwd) $
+			curr <- getCurrentDirectory
+			unless (d `dirContains` curr) $
 				setCurrentDirectory d
 			return $ addworktree wt r
   where
 	pathenv s = do
-#ifndef mingw32_HOST_OS
 		v <- getEnv s
 		case v of
 			Just d -> do
-				void $ unsetEnv s
+				unsetEnv s
 				Just <$> absPath d
 			Nothing -> return Nothing
-#else
-		return Nothing
-#endif
 
 	configure Nothing (Just r) = Git.Config.read r
 	configure (Just d) _ = do
 		absd <- absPath d
-		cwd <- getCurrentDirectory
-		r <- newFrom $ Local { gitdir = absd, worktree = Just cwd }
+		curr <- getCurrentDirectory
+		r <- newFrom $ Local { gitdir = absd, worktree = Just curr }
 		Git.Config.read r
 	configure Nothing Nothing = error "Not in a git repository."
 
