@@ -7,6 +7,8 @@
 
 module Git.Index where
 
+import Common
+import Git
 import Utility.Env
 
 {- Forces git to use the specified index file.
@@ -25,3 +27,10 @@ override index = do
 	var = "GIT_INDEX_FILE"
 	reset (Just v) = setEnv var v True
 	reset _ = unsetEnv var
+
+indexFile :: Repo -> FilePath
+indexFile r = localGitDir r </> "index"
+
+{- Git locks the index by creating this file. -}
+indexFileLock :: Repo -> FilePath
+indexFileLock r = indexFile r ++ ".lock"
