@@ -2,7 +2,7 @@
  -
  - Copyright 2012 Joey Hess <joey@kitenet.net>
  -
- - Licensed under the GNU GPL version 3 or higher.
+ - License: BSD-2-clause
  -}
 
 {-# LANGUAGE CPP #-}
@@ -11,17 +11,14 @@ module Utility.LogFile where
 
 import Common
 
-import System.Posix.Types
-
-openLog :: FilePath -> IO Fd
 #ifndef mingw32_HOST_OS
+import System.Posix.Types
+#endif
+
+openLog :: FilePath -> IO Handle
 openLog logfile = do
 	rotateLog logfile
-	openFd logfile WriteOnly (Just stdFileMode)
-		defaultFileFlags { append = True }
-#else
-openLog = error "openLog TODO"
-#endif
+	openFile logfile AppendMode
 
 rotateLog :: FilePath -> IO ()
 rotateLog logfile = go 0
@@ -30,7 +27,7 @@ rotateLog logfile = go 0
 		| num > maxLogs = return ()
 		| otherwise = whenM (doesFileExist currfile) $ do
 			go (num + 1)
-			renameFile currfile nextfile
+			rename currfile nextfile
 	  where
 		currfile = filename num
 		nextfile = filename (num + 1)
@@ -49,20 +46,14 @@ listLogs logfile = filterM doesFileExist $ reverse $
 maxLogs :: Int
 maxLogs = 9
 
-redirLog :: Fd -> IO ()
 #ifndef mingw32_HOST_OS
+redirLog :: Fd -> IO ()
 redirLog logfd = do
 	mapM_ (redir logfd) [stdOutput, stdError]
 	closeFd logfd
-#else
-redirLog _ = error "redirLog TODO"
-#endif
 
 redir :: Fd -> Fd -> IO ()
-#ifndef mingw32_HOST_OS
 redir newh h = do
 	closeFd h
 	void $ dupTo newh h
-#else
-redir _ _ = error "redir TODO"
 #endif
